package mv3302;

import java.awt.geom.Point2D;
import simkit.smd.Mover;

/**
 * Similar to PathMoverManager; directs a Mover to a sequence of way points.
 * Instead of stopping at the end, return to the first and cycle through again
 * until stopped by an external component.
 *
 * @author dansl
 */
public class SimplePatrolMoverManager extends SimplePathMoverManager {

    /**
     * Zero argument constructor
     */
    public SimplePatrolMoverManager() {
    }

    /**
     * Instantiate with the given parameters
     *
     * @param path Given path
     * @param startOnRun if true, start on Run event
     */
    public SimplePatrolMoverManager(Point2D[] path, boolean startOnRun) {
        super(path, startOnRun);
    }

    /**
     * Always schedule NextWayPoint
     *
     * @param mover Given Mover
     */
    @Override
    public void doEndMove(Mover mover) {
        waitDelay("NextWaypoint", 0.0);

    }

    /**
     * Increment nextIndext and set modulo the length of the path<br>
     * setNextDestination<br>
     * Schedule MoveTo
     */
    public void doNextWaypoint() {
        int oldNextIndex = getNextIndex();
        nextIndex = (nextIndex + 1) % getPath().length;
        firePropertyChange("nextIndex", oldNextIndex, getNextIndex());

        Point2D oldDestination = getNextDestination();
        nextDestination.setLocation(getPath(nextIndex));
        firePropertyChange("nextDestination", oldDestination, getNextDestination());

        waitDelay("MoveTo", 0.0, getNextDestination());
    }

}
